SystemOrganization addCategory: #'PW-PEG'!

TestCase subclass: #PWActorTests
	instanceVariableNames: 'parser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-PEG'!

!PWActorTests commentStamp: '<historical>' prior: 0!
A terminal here is an OrderedCollection that does not contain another OrderedCollection. A terminal's contents is chars or strings. In the #grammarWiki that could be: 

Bold <- "*" Flow{"*"}

Angle brackets (i.e. {}) show that something is optional. To create a bold word you need an asterisk befor a or line. It will not contain any further OrderedCollections.  !

!PWActorTests methodsFor: 'page structure' stamp: 'chc 1/3/2016 01:41'!
setUp
	| grammar |
	grammar := PEGParser grammarWiki.
	parser := PEGParser parserPEG parse: 'Grammar' stream: grammar actor: PEGParserParser new.
	! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:45'!
testBold
	| result |
	result := parser parse: 'Bold' stream: '*Taco Bell*' actor: PWActor new.
	self assert: ( '<b>Taco Bell</b>' = result )! !

!PWActorTests methodsFor: 'double node' stamp: 'chc 2/23/2016 12:42'!
testBullet1
	| result |
	result := parser parse: 'Bullet1' stream: ' *First Item' actor: PWActor new.
	self assert: ( '<li>First Item</li>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:43'!
testCode
	| result |
	result := parser parse: 'Code' stream: '{{{
code
}}}' actor: PWActor new.
	self assert: ( '<pre>
code
</pre>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:46'!
testHeading1
	| result |
	result := parser parse: 'Heading1' stream: '  = BigDay =
				' actor: PWActor new.
	self assert: ( '<h1>BigDay</h1>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:46'!
testHeading2
	| result |
	result := parser parse: 'Heading2' stream: '  == BigDay ==
				' actor: PWActor new.
	self assert: ( '<h2>BigDay</h2>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:46'!
testHeading3
	| result |
	result := parser parse: 'Heading3' stream: '  === BigDay ===
				' actor: PWActor new.
	self assert: ( '<h3>BigDay</h3>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:47'!
testItalic
	| result |
	result := parser parse: 'Italic' stream: '_Taco Bell_' actor: PWActor new.
	self assert: ( '<i>Taco Bell</i>' = result )! !

!PWActorTests methodsFor: 'single node ' stamp: 'chc 2/23/2016 12:47'!
testLink
	| result |
	result := parser parse: 'LinkShort' stream: '[abc]' actor: PWActor new.
	self assert: ( '<a href="http://www.abc.com">abc</a>' = result )! !

!PWActorTests methodsFor: 'page structure' stamp: 'chc 2/23/2016 12:46'!
testPage
	| result |
	result := parser parse: 'Page' stream: 'Taco Bell' actor: PWActor new.
	self assert: ( '<div><p>Taco Bell</p></div>' = result )! !

TestCase subclass: #PWPEGParserTests
	instanceVariableNames: 'parser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-PEG'!

!PWPEGParserTests commentStamp: '<historical>' prior: 0!
A terminal here is an OrderedCollection that does not contain another OrderedCollection. A terminal's contents is chars or strings. In the #grammarWiki that could be: 

Bold <- "*" Flow{"*"}

Angle brackets (i.e. {}) show that something is optional. To create a bold word you need an asterisk befor a or line. It will not contain any further OrderedCollections.  !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 2/23/2016 23:04'!
setUp
	| grammar |
	grammar := PEGParser grammarWiki.
	parser := PEGParser parserPEG parse: 'Grammar' stream: grammar actor: PEGParserParser new.
	! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 2/23/2016 23:00'!
testEmpty
	| result oc1 oc2 |
	result := parser parse: 'Empty' stream: '
	' reading actor: nil.
	oc1 := OrderedCollection new. 
	oc2 := OrderedCollection new.
	oc2 add: Character tab.
	oc1 add: oc2.
	self assert: ( oc1 = result )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 2/23/2016 23:00'!
testLIneCharacter
	| result oc1 oc2 |
	result := parser parse: 'LineCharacter' stream: '
	' reading actor: nil.
	oc1 := OrderedCollection new. 
	oc2 := OrderedCollection new.
	oc2 add: Character tab.
	oc1 add: oc2.
	self assert: ( oc1 = result )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 2/23/2016 23:12'!
testLine
	| result |
	result := parser parse: 'LinkShort' stream: '[abc]' actor: nil.
	self assert: ( '<a href="http://www.abc.com">abc</a>' = result )! !

!PWPEGParserTests methodsFor: 'empty space identifiers' stamp: 'chc 2/23/2016 23:00'!
testWhitespace
	| result oc1 oc2 chars |
	result := parser parse: 'Whitespace' stream: '		  ' actor: nil.
	oc1 := OrderedCollection new. 
	oc2 := OrderedCollection new.
	oc1 add: Character tab; add: Character tab; add: Character space; add: Character space.
	chars := oc2 add: oc1.
	self assert: ( chars = result )! !

PEGActor subclass: #PWActor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PW-PEG'!

!PWActor commentStamp: 'chc 3/22/2016 09:29' prior: 0!
This class renders OrderedCollections and Arrays parsed by the #grammarWiki in the PEGParser into HTML. !

!PWActor methodsFor: 'argument' stamp: 'chc 11/25/2015 19:27'!
Bold: flow
	<action: 'Bold' arguments: #(2)>
	^'<b>' , (self collectString: flow) , '</b>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 3/22/2016 10:19'!
Bullet1: flow
	<action: 'Bullet1' arguments: #(3)>
	^'<li>' , (self collectString: flow) , '</li>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 11/25/2015 19:27'!
Heading1: flow
	<action: 'Heading1' arguments: #(3) >
	^'<h1>' , (self collectString: flow) , '</h1>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 11/25/2015 19:27'!
Heading2: flow
	<action: 'Heading2' arguments: #(3) >
	^'<h2>' , (self collectString: flow) , '</h2>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 11/25/2015 19:27'!
Heading3: flow
	<action: 'Heading3' arguments: #(3) >
	^'<h3>' , (self collectString: flow) , '</h3>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 3/24/2016 09:54'!
Italic: flow
	<action: 'Italic' arguments: #(2)>
	^'<i>' , (self collectString: flow) , '</i>'
	
	"^(Character value: 16ra3) asString , (self collectString: flow) , (Character value: 16ra3) asString"! !

!PWActor methodsFor: 'argument' stamp: 'chc 3/30/2016 09:16'!
Link: flow
	<action: 'LinkShort' arguments: #( 2 )>
	| linkContent |
	linkContent := self collectString: flow.
	^'<a href="' , linkContent , '">' , linkContent , '</a>'! !

!PWActor methodsFor: 'no-argument' stamp: 'chc 1/2/2016 13:19'!
Page: flow
	<action: 'Page'>
	^'<div>' , (self collectString: flow) , '</div>'! !

!PWActor methodsFor: 'no-argument' stamp: 'chc 11/25/2015 19:28'!
Paragraph: flow
	<action: 'Paragraph'>
	^'<p>' , (self collectString: flow) , '</p>'! !

!PWActor methodsFor: 'argument' stamp: 'chc 3/22/2016 10:17'!
UnorderedList: flow
	<action: 'UnorderedList'>
	^'<ul>' , (self collectString: flow) , '</ul>'! !

!PWActor methodsFor: 'private' stamp: 'chc 11/25/2015 19:27'!
collectString: flow
	| string |
	string := String new writing.
	flow do: [:ea| string write: ea].
	^string conclusion! !
